ubuntuusers.de

Heute zwischen 20:30 und 21:30 wird https://ubuntuusers.de/ für längere Zeit nicht erreichbar sein, da das OS der Server und die Datenbank aktualisiert werden.

growisofs und libburn-basierte Programme - /home/undine - sichtbare Dateien

Status: Ungelöst | Ubuntu-Version: Server 22.04 (Jammy Jellyfish)
Antworten |

undine

Anmeldungsdatum:
25. Januar 2007

Beiträge: 3400

Hallo Users,

https://wiki.ubuntuusers.de/cdrecord/

wie muss eine Kommandozeile aussehen und die sichtbaren Dateien aus /home/undine auf eine DVD-RW zu schreiben?

https://www.fim.uni-passau.de/it-dienste/rechnerpools/hardware/brennen-von-cds-und-dvd-ueber-shell-kommandos

https://wiki.ubuntuusers.de/wodim/

Weder wodim noch cdrecord sind bei DVD und BD erste Wahl. growisofs und libburn-basierte Programme bieten mehr Möglichkeiten im Bezug auf Formatierung und Multi-Session. Das libburn-Programm cdrskin versteht viele der Optionen von wodim und kann es in den Anwendungsfällen CD-DA (Audio) und CD-ROM (Daten) ersetzen.

https://wiki.ubuntuusers.de/Brennprogramme/

https://wiki.ubuntuusers.de/Brennprogramme/#Kommandozeile

apt search cdrskin Sortierung… Fertig Volltextsuche… Fertig cdrskin/jammy 1.5.4-1 amd64 Befehlszeilenprogramm zum Schreiben von CD/DVD/BD

x –- mein Favorit ––→ growisofs

dvd+rw-tools/jammy,now 7.1-14build1 amd64 [Installiert,automatisch] DVD+-RW/R-Werkzeuge

growisofs/jammy,now 7.1-14build1 amd64 [installiert] DVD+-RW/R-Rekorder

https://baireuther.de/lhb/growisofs/

growisofs -dvd-compat -Z /dev/dvd -J -r -V "Meine Sicherung" /pfad/zu/den/daten/ 

-

Erklärung der einzelnen Schalter:

    -dvd-compat: garantiert größtmögliche Kompatibilität (closed, fixed,… – wie man es auch nennen mag)
    -Z /dev/dvd: die Gerätedatei des Brenners
    -J: Joliet Erweiterung (um sie auch in Windows lesen zu können)
    -r: Rockrigde Erweiterung (für Unix/Linux)
    -V: gibt der DVD (und auch CD) einen Namen. Die Anführungszeichen sind wichtig, wenn ein Leerzeichen dabei ist.
    /pfad/zu/den/daten/: die Daten in diesem Ordner werden gebrannt

Greetz

undine

scdbackup

Anmeldungsdatum:
7. November 2013

Beiträge: 171

Hi,

die Entsprechung zum growisofs Lauf mit einem libburn Programm waere:

xorriso -for_backup -outdev /dev/dvd -joliet on -volid "Meine Sicherung" \
        -map /pfad/zu/den/daten/ / -close on

Erklaerung der einzelnen xorriso Befehle:

-for_backup : Stattet das Filesystem und jeden einzelnen Datenfile mit einer
              MD5 Pruefsumme aus, mit der man spaeter die Unversehrtheit
              der Daten pruefen kann:
                xorriso -for_backup -indev /dev/dvd -check_media --
-outdev : Gibt den Geraetefile des Brenners an.
-joliet on : Erzeugt einen Joliet-Baum, der lange Filenamen fuer MS-Windows
              enthaelt. (Sonst kann Windows nur die kurzen, dummen ISO 9660
              Filenamen zeigen. Auf Linux sieht man sie nach:
                mount -o norock,nojoliet /dev/dvd /mnt/iso
              )
-volid : Gibt das Volume Id an, das von Linux als "LABEL" des Filesystems
              verwendet wird.
-map : Gibt den Pfad eines Files oder Directory-Baums an und danach
              den Pfad, den die Kopie dann im ISO 9660 / Rock Ridge Filesystem
              haben soll. (Man kann mehrere -map Befehle verwenden.)
-close on :  Bestellt, dass die DVD-RW nach dem Schreiben geschlossen wird,
              also bis zum naechsten Blanken keine Daten mehr annimmt.
(Die Reihenfolge der Befehle spielt dabei eine wichtige Rolle.)

Die Entsprechung der mkisofs Option -r habe ich weggelassen, weil sie die Zugriffsrechte der Files im ISO 9660 / Rock Ridge Filesystem krass aendert. Bei einer Sicherungskopie will man die aber erhalten. In xorriso ginge das mit einem weiteren Befehl:

-find / -exec mkisofs_r --

Ich wuerde fuer growisofs+mkisofs statt -r die Option -R empfehlen. Die verursacht Rock Ridge ohne Aenderungen an den Rechten.

growisofs braucht fuer den obigen Lauf noch ein Programm zur Erzeugung von ISO 9660 Filesystemen: mkisofs, genisoimage, xorrisofs. (Letzteres ist der mkisofs-Emulationsmodus von xorriso.)

Die libburn-Programme cdrskin oder xorrecord wuerde man wie cdrecord oder wodim in einer Pipe mit so einem ISO 9660 Programm benutzen:

xorrisofs -J -R -V "Meine Sicherung" /pfad/zu/den/daten/ | \
cdrskin dev=/dev/dvd -v -eject -

Have a nice day ☺

Thomas

undine

(Themenstarter)

Anmeldungsdatum:
25. Januar 2007

Beiträge: 3400

x –- mein Favorit ––→ growisofs

Wie funktioniert das mit growisofs?

scdbackup

Anmeldungsdatum:
7. November 2013

Beiträge: 171

Hi,

Wie funktioniert das mit growisofs?

Meinst Du das mit den MD5 Pruefsummen ? Da musst Du growisofs die mkisofs-Emulation von xorriso unterschieben, um deren Option --for_backup dazugeben zu koennen:

export GENISOIMAGE=xorrisofs
growisofs -dvd-compat -Z /dev/dvd --for_backup -J -R -V "Meine Sicherung" /pfad/zu/den/daten/

Im originalen growisofs heisst die Variable MKISOFS. Aber Debian hat den Variablennamen auf GENISOIMAGE geaendert. Siehe auch man growisofs. (Die man-Page von xorrisofs ist etwa 10-mal laenger als die von growisofs und erklaert die Optionen, die growisofs nicht fuer sich selbst rauspickt.)

Falls Du fragst, wie man growisofs als brennendes Ende einer Pipe benutzt:

 Anfang der Pipe ... | growisofs -dvd-compat -Z /dev/dvd=/dev/fd/0

/dev/fd/0 ist keine Floppy, sondern die Repraesentation des Filedescriptors 0 des zugreifenden Prozesses, auch bekannt als Standard Input.

Have a nice day ☺

Thomas

undine

(Themenstarter)

Anmeldungsdatum:
25. Januar 2007

Beiträge: 3400

Eine Anleitung suche ich um die Daten /home/user auf eine DVD-RW zu brennen.

Eine GUI ist nicht vorhanden.

scdbackup

Anmeldungsdatum:
7. November 2013

Beiträge: 171

Hi,

Eine Anleitung suche ich um die Daten /home/user auf eine DVD-RW zu brennen.

Funktioniert denn Dein Vorschlag mit growisofs nicht ?

growisofs -dvd-compat -Z /dev/dvd -J -R -V "Meine Sicherung" /home/user

Falls ja: Wie aeussert sich das Nichtfunktionieren ? Fehlermeldungen ? Unlesbare DVD ? Passt /home/user ueberhaupt auf eine DVD (4482 MiB) ?

Have a nice day ☺

Thomas

undine

(Themenstarter)

Anmeldungsdatum:
25. Januar 2007

Beiträge: 3400

Passt /home/user ueberhaupt auf eine DVD (4482 MiB) ?

Genau da liegt das Problem, ich möcht nur "sichtbare" Dateien sichern, das passt dann.

Wie lautet dann der Befehl?

scdbackup

Anmeldungsdatum:
7. November 2013

Beiträge: 171

Hi,

wenn mit nicht-"sichtbare" die Files gemeint sind, deren Name mit einem Punkt "." beginnt, dann muesste die Option -m helfen:

growisofs -dvd-compat -Z /dev/dvd -J -R -V "HOME_USER_2023_09_14" -m '.*' /home/user

(Ich habe auch das Volume Id mit einem Text belegt, der spaeter noch sagt, was da auf der DVD ist. Der Text wird gerne als Name des Mountpunkts verwendet, der die DVD zugaenglich macht.)

Ich habe mich ja etwas gewundert, dass das einen erheblichen Unterschied machen soll, aber bei meinem $HOME-Directory faellt die Kopie dadurch etwa 600 MB kleiner aus. Aber bist Du sicher, dass Du diese unsichtbaren Files nicht zu kopieren brauchst ?

Have a nice day ☺

Thomas

schollsky

Anmeldungsdatum:
3. Dezember 2012

Beiträge: 1861

Wohnort: Ruhrgebeat

Das Profilverzeichnis von Firefox lautet z.B.

.mozilla

scdbackup

Anmeldungsdatum:
7. November 2013

Beiträge: 171

Hi,

Das Profilverzeichnis von Firefox lautet z.B. .mozilla

Undine koennte versuchen, ob es reicht die dicksten unsichtbaren Baeume aus /home/user wegzulassen. Bei mir waeren das:

-m .cache -m .googleearth -m .mozilla

Ich wuerde zB. /home/user/.config doch lieber im Backup haben.

Man muss sich ueberlegen, ob die DVD sicher genug verwahrt sein wird, um auch die privaten Schluessel aus /home/user/.ssh enthalten zu duerfen.

Have a nice day ☺

Thomas

Antworten |